@@ -1,5 +1,4 @@
 module Example(fac, main) where
-import Prelude
 
 fac :: Int -> Int
 fac 0 = 1
@@ -7,7 +6,6 @@ fac n = n * fac(n - 1)
 
 main :: IO ()
 main = do
-  let
-    rs = map fac [1,2,3,10]
+  let rs = map fac [1,2,3,10]
   putStrLn "Some factorials"
   print rs
