@@ -4,16 +4,22 @@ module Data.Bool(
   module Data.Bool,
   module Data.Bool_Type
   ) where
+import Prelude()              -- do not import Prelude
 import Primitives
 import Data.Bool_Type
 import Data.Bounded
 import Data.Eq
+import Data.Ord
 import Text.Show
 
 instance Eq Bool where
   False == x  =  not x
   True  == x  =  x
 
+instance Ord Bool where
+  False <= _ = True
+  True  <= x = x
+
 instance Show Bool where
   showsPrec _ False = showString "False"
   showsPrec _ True  = showString "True"
@@ -38,3 +44,7 @@ not True  = False
 
 otherwise :: Bool
 otherwise = True
+
+bool :: forall a . a -> a -> Bool -> a
+bool f _ False = f
+bool _ t True  = t
