@@ -1,4 +1,5 @@
 module Data.Floating(module Data.Floating) where
+import Prelude()              -- do not import Prelude
 import Primitives
 import Data.Fractional
 import Data.Num
@@ -33,8 +34,8 @@ class (Fractional a) => Floating a  where
   logBase x y         = log y / log x
   sqrt x              = x ** (1/2)
   tan  x              = sin  x / cos  x
-  sinh x              = (exp x - exp (negate x)) / 2
-  cosh x              = (exp x + exp (negate x)) / 2
+  sinh x              = (exp x - exp (- x)) / 2
+  cosh x              = (exp x + exp (- x)) / 2
   tanh x              = sinh x / cosh x
   asinh x             = log (x + sqrt (x*x + 1))
   acosh x             = log (x + sqrt (x*x - 1))
@@ -42,4 +43,4 @@ class (Fractional a) => Floating a  where
   log1p x             = log (1 + x)
   expm1 x             = exp x - 1
   log1pexp x          = log1p (exp x)
-  log1mexp x          = log1p (negate (exp x))
+  log1mexp x          = log1p (- (exp x))
