@@ -1,6 +1,7 @@
 -- Copyright 2023 Lennart Augustsson
 -- See LICENSE file for full license.
 module Data.Fractional(module Data.Fractional) where
+import Prelude()              -- do not import Prelude
 import Primitives
 import Data.Integral
 import Data.Num
@@ -16,4 +17,4 @@ class Num a => Fractional a where
 
 infixr 8 ^^
 (^^) :: forall a b . (Fractional a, Integral b, Ord b) => a -> b -> a
-x ^^ n = if n >= 0 then x^n else recip (x^(negate n))
+x ^^ n = if n >= 0 then x^n else recip (x^(- n))
