@@ -1,7 +1,9 @@
 -- Copyright 2023 Lennart Augustsson
 -- See LICENSE file for full license.
 module Data.Function(module Data.Function) where
+import Prelude()              -- do not import Prelude
 import Primitives
+import Data.Bool_Type
 --import Data.Tuple
 
 infixr 0 $
@@ -28,12 +30,25 @@ flip f a b = f b a
 fix :: forall a . (a -> a) -> a
 fix = primFix
 
-uncurry :: forall a b c . (a -> b -> c) -> (a, b) -> c
-uncurry f (a, b) = f a b  -- XXX not lazy
-
 infixl 0 `on`
 on :: forall a b c . (a -> a -> b) -> (c -> a) -> (c -> c -> b)
 on op sel x y = op (sel x) (sel y)
 
 asTypeOf :: forall a . a -> a -> a
 asTypeOf = const
+
+seq :: forall a b . a -> b -> b
+seq = primSeq
+
+until :: forall a . (a -> Bool) -> (a -> a) -> a -> a
+until p f = rec
+  where
+    rec x = if p x then x else rec (f x)
+
+infixl 1 &
+(&) :: forall a b . a -> (a -> b) -> b
+(&) x f = f x
+
+applyWhen :: forall a . Bool -> (a -> a) -> a -> a
+applyWhen True  f x = f x
+applyWhen False _ x = x
