@@ -1,5 +1,5 @@
 module Debug.Trace(module Debug.Trace) where
-import Prelude
+import Prelude(); import MiniPrelude
 import Primitives
 
 trace :: forall a . String -> a -> a
@@ -9,5 +9,5 @@ trace msg a = primitive "IO.performIO" (
     return a
   )
 
-traceM :: forall (m :: Type -> Type) a . Monad m => String -> m ()
+traceM :: forall m . Monad m => String -> m ()
 traceM s = trace s (return ())
