@@ -1,5 +1,6 @@
 module System.Process(callCommand) where
-import Prelude
+import Prelude(); import MiniPrelude
+import Control.Monad(when)
 import Foreign.C.String
 
 foreign import ccall "system" systemc :: CString -> IO Int
@@ -8,4 +9,4 @@ callCommand :: String -> IO ()
 callCommand cmd = do
   r <- withCAString cmd systemc
   when (r /= 0) $
-    error $ "callCommand: failed " ++ show r
+    error $ "callCommand: failed " ++ show r ++ ", " ++ show cmd
