@@ -20,15 +20,25 @@
  */
 #define WANT_MATH 1
 
+/*
+ * Include MD5 checksumming code
+ */
+#define WANT_MD5 1
+
+/*
+ * Include profiling code
+ */
+#define WANT_TICK 1
+
 /*
  * Number of bits in a word.  Only 32 and 64 are supported.
  */
-#define WORD_SIZE 64
+//#define WORD_SIZE 64
 
 /*
  * Find First Set
  * This macro must be defined.
- * It return the number of the least significant bit that is set.
+ * It returns the number of the least significant bit that is set.
  * Numberings starts from 1.  If no bit is set, it should return 0.
  */
 #define FFS __builtin_ffsll
