@@ -3,6 +3,6 @@ import Prelude
 
 main :: IO ()
 main = do
-  print $ log (1000::Double)
+  print $ logBase 10 (1000::Double)
   print $ cos (pi::Double)
   print $ sqrt (4::Double)
