@@ -1,12 +1,10 @@
 module IOTest(module IOTest) where
 import Prelude
 import System.IO as IO
+import System.IO.TimeMilli
 import System.Environment
 import Debug.Trace
 
-f :: Int -> Int
-f x = x*2+1
-
 foo :: IO ()
 foo = do
   putStrLn "foo 1"
@@ -23,7 +21,6 @@ main = do
   p
   p
   p
-  cprint ((+) :: Int->Int->Int)
   hout <- openFile "test.tmp" WriteMode
   hPutChar hout 'a'
   hPutChar hout 'z'
@@ -35,9 +32,6 @@ main = do
   writeFile "test2.tmp" "more\n"
   s <- readFile "test2.tmp"
   putStrLn (show s)
-  writeSerialized "f.tmp" f
-  g <- readSerialized "f.tmp"
-  putStrLn $ show $ (g (5::Int) :: Int)
   foo
   putStrLn $ show $ trace "tracing" (5::Int)
   as <- getArgs
