@@ -1,5 +1,5 @@
-module Nfib(main) where
-import Prelude
+module Nfib(main, nfib) where
+import System.IO.TimeMilli(getTimeMilli)
 
 nfib :: Int -> Int
 nfib n =
@@ -8,7 +8,12 @@ nfib n =
     True  -> 1
 
 main :: IO ()
-main = print (nfib 44)
+main = do
+  t1 <- getTimeMilli
+  let r = nfib 37
+  print r
+  t2 <- getTimeMilli
+  putStrLn $ "nfib/s = " ++ show (r `quot` (t2 - t1)) ++ "k"
 
 -- Typical nfib/s is 10M
 -- mhs
